#  tests for python-snappy-0.6.0-py36hd77b12b_3 (this is a generated file);
print('===== testing package: python-snappy-0.6.0-py36hd77b12b_3 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import snappy

s = u"this is a very very basic correctness test".encode('utf-8')
assert snappy.uncompress(snappy.compress(s)) == s
#  --- run_test.py (end) ---

print('===== python-snappy-0.6.0-py36hd77b12b_3 OK =====');
print("import: 'snappy'")
import snappy

